@@ -9,6 +9,7 @@ from .heater import GeckoWaterHeater
 from .keypad import GeckoKeypad
 from .light import GeckoLight
 from .pump import GeckoPump
+from .reminders import GeckoReminders
 from .sensors import GeckoSensor, GeckoBinarySensor
 from .switch import GeckoSwitch
 from .watercare import GeckoWaterCare
@@ -28,4 +29,5 @@ __all__ = [
     "GeckoBinarySensor",
     "GeckoSwitch",
     "GeckoWaterCare",
+    "GeckoReminders",
 ]
